# Model-insight

Description
============

This is a package for students to learn mathematical modeling and solve some modeling problems.

Installing
============

Use  `pip`

    pip install model-insight==0.3.5

Usage
=====
    import model_insight

